@@ -37,11 +37,43 @@ API struct ncdirect* ncdirect_init(const char* termtype, FILE* fp, uint64_t flag
 // Direct mode. This API can be used to colorize and stylize output generated
 // outside of notcurses, without ever calling notcurses_render(). These should
 // not be intermixed with standard Notcurses rendering.
-API int ncdirect_fg_rgb(struct ncdirect* nc, unsigned rgb);
-API int ncdirect_bg_rgb(struct ncdirect* nc, unsigned rgb);
+API int ncdirect_set_fg_rgb(struct ncdirect* nc, unsigned rgb);
+API int ncdirect_set_bg_rgb(struct ncdirect* nc, unsigned rgb);
 
-API int ncdirect_fg_palindex(struct ncdirect* nc, int pidx);
-API int ncdirect_bg_palindex(struct ncdirect* nc, int pidx);
+static inline int ncdirect_fg_rgb(struct ncdirect* nc, unsigned rgb)
+  __attribute__ ((deprecated));
+
+static inline int
+ncdirect_fg_rgb(struct ncdirect* nc, unsigned rgb){
+  return ncdirect_set_fg_rgb(nc, rgb);
+}
+
+static inline int ncdirect_bg_rgb(struct ncdirect* nc, unsigned rgb)
+  __attribute__ ((deprecated));
+
+static inline int
+ncdirect_bg_rgb(struct ncdirect* nc, unsigned rgb){
+  return ncdirect_set_bg_rgb(nc, rgb);
+}
+
+API int ncdirect_set_fg_palindex(struct ncdirect* nc, int pidx);
+API int ncdirect_set_bg_palindex(struct ncdirect* nc, int pidx);
+
+static inline int ncdirect_fg_palindex(struct ncdirect* nc, int pidx)
+  __attribute__ ((deprecated));
+
+static inline int
+ncdirect_fg_palindex(struct ncdirect* nc, int pidx){
+  return ncdirect_set_fg_palindex(nc, pidx);
+}
+
+static inline int ncdirect_bg_palindex(struct ncdirect* nc, int pidx)
+  __attribute__ ((deprecated));
+
+static inline int
+ncdirect_bg_palindex(struct ncdirect* nc, int pidx){
+  return ncdirect_set_bg_palindex(nc, pidx);
+}
 
 // Returns the number of simultaneous colors claimed to be supported, or 1 if
 // there is no color support. Note that several terminal emulators advertise
@@ -63,32 +95,74 @@ API int ncdirect_printf_aligned(struct ncdirect* n, int y, ncalign_e align,
 API int ncdirect_flush(const struct ncdirect* nc);
 
 static inline int
-ncdirect_bg_rgb8(struct ncdirect* nc, unsigned r, unsigned g, unsigned b){
+ncdirect_set_bg_rgb8(struct ncdirect* nc, unsigned r, unsigned g, unsigned b){
   if(r > 255 || g > 255 || b > 255){
     return -1;
   }
-  return ncdirect_bg_rgb(nc, (r << 16u) + (g << 8u) + b);
+  return ncdirect_set_bg_rgb(nc, (r << 16u) + (g << 8u) + b);
 }
 
 static inline int
-ncdirect_fg_rgb8(struct ncdirect* nc, unsigned r, unsigned g, unsigned b){
+ncdirect_set_fg_rgb8(struct ncdirect* nc, unsigned r, unsigned g, unsigned b){
   if(r > 255 || g > 255 || b > 255){
     return -1;
   }
-  return ncdirect_fg_rgb(nc, (r << 16u) + (g << 8u) + b);
+  return ncdirect_set_fg_rgb(nc, (r << 16u) + (g << 8u) + b);
 }
 
-API int ncdirect_fg_default(struct ncdirect* nc);
-API int ncdirect_bg_default(struct ncdirect* nc);
+static inline int
+ncdirect_fg_rgb8(struct ncdirect* nc, unsigned r, unsigned g, unsigned b)
+  __attribute__ ((deprecated));
+
+static inline int
+ncdirect_fg_rgb8(struct ncdirect* nc, unsigned r, unsigned g, unsigned b){
+  return ncdirect_set_fg_rgb8(nc, r, g, b);
+}
+
+static inline int
+ncdirect_bg_rgb8(struct ncdirect* nc, unsigned r, unsigned g, unsigned b)
+  __attribute__ ((deprecated));
+
+static inline int
+ncdirect_bg_rgb8(struct ncdirect* nc, unsigned r, unsigned g, unsigned b){
+  return ncdirect_set_bg_rgb8(nc, r, g, b);
+}
+
+API int ncdirect_set_fg_default(struct ncdirect* nc);
+API int ncdirect_set_bg_default(struct ncdirect* nc);
+
+static inline int ncdirect_fg_default(struct ncdirect* nc)
+  __attribute__ ((deprecated));
+
+static inline int
+ncdirect_fg_default(struct ncdirect* nc){
+  return ncdirect_set_fg_default(nc);
+}
+
+static inline int ncdirect_bg_default(struct ncdirect* nc)
+  __attribute__ ((deprecated));
+
+static inline int
+ncdirect_bg_default(struct ncdirect* nc){
+  return ncdirect_set_bg_default(nc);
+}
 
 // Get the current number of columns/rows.
 API int ncdirect_dim_x(const struct ncdirect* nc);
 API int ncdirect_dim_y(const struct ncdirect* nc);
 
 // ncplane_styles_*() analogues
-API int ncdirect_styles_set(struct ncdirect* n, unsigned stylebits);
-API int ncdirect_styles_on(struct ncdirect* n, unsigned stylebits);
-API int ncdirect_styles_off(struct ncdirect* n, unsigned stylebits);
+API int ncdirect_set_styles(struct ncdirect* n, unsigned stylebits);
+API int ncdirect_on_styles(struct ncdirect* n, unsigned stylebits);
+API int ncdirect_off_styles(struct ncdirect* n, unsigned stylebits);
+
+// Deprecated forms of above.
+API int ncdirect_styles_set(struct ncdirect* n, unsigned stylebits)
+  __attribute__ ((deprecated));
+API int ncdirect_styles_on(struct ncdirect* n, unsigned stylebits)
+  __attribute__ ((deprecated));
+API int ncdirect_styles_off(struct ncdirect* n, unsigned stylebits)
+  __attribute__ ((deprecated));
 
 // Move the cursor in direct mode. -1 to retain current location on that axis.
 API int ncdirect_cursor_move_yx(struct ncdirect* n, int y, int x);
@@ -199,12 +273,8 @@ API int ncdirect_stop(struct ncdirect* nc);
 API ncdirectv* ncdirect_render_frame(struct ncdirect* n, const char* filename,
                                      ncblitter_e blitter, ncscale_e scale);
 
-// Takes the result of ncdirect_render_frame() and writes it to the output. The
-// 'align', 'blitter', and 'scale' arguments must be the same as those passed
-// to ncdirect_render_frame().
-API int ncdirect_raster_frame(struct ncdirect* n, ncdirectv* faken,
-                              ncalign_e align, ncblitter_e blitter,
-                              ncscale_e scale);
+// Takes the result of ncdirect_render_frame() and writes it to the output.
+API int ncdirect_raster_frame(struct ncdirect* n, ncdirectv* ncdv, ncalign_e align);
 
 #undef API
 
