@@ -5,12 +5,12 @@
 
 use libnotcurses_sys::*;
 
-fn main() {
+fn main() -> NcResult<()> {
     let nc = Notcurses::with_flags(
         NCOPTION_SUPPRESS_BANNERS
         | NCOPTION_NO_WINCH_SIGHANDLER
         | NCOPTION_NO_QUIT_SIGHANDLERS
-        );
+        )?;
 
     // doesn't seem to be necessary:
     // let ready = unsafe { notcurses_inputready_fd(nc) };
@@ -27,7 +27,7 @@ fn main() {
             println!("'{0}' ({1:x})\n{2:?}", key, key as u32, input);
         }
 
-        rsleep![nc, 100];
+        rsleep![nc, 0, 10];
 
         match key {
             NCKEY_F01 => break,
@@ -37,6 +37,7 @@ fn main() {
 
     println!("\nExiting...");
 
-    rsleep![nc, 1000];
-    nc.stop();
+    rsleep![nc, 1, 500];
+    nc.stop()?;
+    Ok(())
 }
