@@ -5,7 +5,7 @@ use libnotcurses_sys::*;
 fn main() -> NcResult<()> {
 
     let nc = Notcurses::new()?;
-    let plane = nc.stdplane();
+    let plane = nc.stdplane()?;
     plane.set_scrolling(true);
 
     let mut wc = '\u{4e00}'; // 一
