@@ -3,10 +3,10 @@
 use core::ptr::{null, null_mut};
 
 use crate::{
-    cstring, error, notcurses_init, rstring, NcAlign, NcBlitter, NcChannelPair, NcDimension, NcEgc,
-    NcError, NcFile, NcInput, NcLogLevel, NcPlane, NcResult, NcScale, NcSignalSet, NcStats,
-    NcStyleMask, NcTime, Notcurses, NotcursesOptions, NCOPTION_NO_ALTERNATE_SCREEN,
-    NCOPTION_SUPPRESS_BANNERS, NCRESULT_ERR,
+    cstring, error, error_ref_mut, notcurses_init, rstring, NcAlign, NcBlitter, NcChannelPair,
+    NcDimension, NcEgc, NcError, NcFile, NcInput, NcLogLevel, NcPlane, NcResult, NcScale,
+    NcSignalSet, NcStats, NcStyleMask, NcTime, Notcurses, NotcursesOptions,
+    NCOPTION_NO_ALTERNATE_SCREEN, NCOPTION_SUPPRESS_BANNERS, NCRESULT_ERR,
 };
 
 /// # `NotcursesOptions` Constructors
@@ -97,12 +97,12 @@ impl Notcurses {
 
     /// Returns a Notcurses context, without an alternate screen (nor banners).
     pub fn without_altscreen<'a>() -> NcResult<&'a mut Notcurses> {
-        Self::with_flags(NCOPTION_NO_ALTERNATE_SCREEN | NCOPTION_SUPPRESS_BANNERS)
+        Self::with_flags(NCOPTION_NO_ALTERNATE_SCREEN)
     }
 
     /// Returns a Notcurses context, without an alternate screen, with banners.
     pub fn without_altscreen_nor_banners<'a>() -> NcResult<&'a mut Notcurses> {
-        Self::with_flags(NCOPTION_NO_ALTERNATE_SCREEN)
+        Self::with_flags(NCOPTION_NO_ALTERNATE_SCREEN | NCOPTION_SUPPRESS_BANNERS)
     }
 
     /// Returns a Notcurses context, expects [NotcursesOptions].
@@ -113,10 +113,14 @@ impl Notcurses {
     /// Returns a Notcurses context, expects [NotcursesOptions].
     pub fn with_options<'a>(options: NotcursesOptions) -> NcResult<&'a mut Notcurses> {
         let res = unsafe { notcurses_init(&options, null_mut()) };
-        if res == null_mut() {
-            return Err(NcError::with_msg(NCRESULT_ERR, "Initializing Notcurses"));
-        }
-        Ok(unsafe { &mut *res })
+        error_ref_mut![res, "Notcurses.with_options()"]
+    }
+
+    /// Returns a Notcurses context. Expects [NcLogLevel] and flags.
+    pub fn with_debug<'a>(loglevel: NcLogLevel, flags: u64) -> NcResult<&'a mut Notcurses> {
+        Self::with_options(NotcursesOptions::with_all_options(
+            loglevel, 0, 0, 0, 0, flags,
+        ))
     }
 }
 
@@ -207,6 +211,13 @@ impl Notcurses {
         unsafe { crate::notcurses_cansixel(self) }
     }
 
+    /// Returns true if we can reliably use Unicode 13 sextants.
+    ///
+    /// *C style function: [notcurses_cansextant()][crate::notcurses_cansextant].*
+    pub fn cansextant(&self) -> bool {
+        unsafe { crate::notcurses_cansextant(self) }
+    }
+
     /// Returns true if it's possible to directly specify RGB values per cell,
     /// or false if it's only possible to use palettes.
     ///
@@ -312,16 +323,41 @@ impl Notcurses {
         Ok(c)
     }
 
+    /// If no event is ready, returns 0.
     ///
     /// *C style function: [notcurses_getc_nblock()][crate::notcurses_getc_nblock].*
     pub fn getc_nblock(&mut self, input: &mut NcInput) -> char {
         crate::notcurses_getc_nblock(self, input)
     }
 
+    /// Blocks until a codepoint or special key is read,
+    /// or until interrupted by a signal.
     ///
-    /// *C style function: [notcurses_getc_nblocking()][crate::notcurses_getc_nblocking].*
-    pub fn getc_nblocking(&mut self, input: &mut NcInput) -> char {
-        crate::notcurses_getc_nblocking(self, input)
+    /// In the case of a valid read, a 32-bit Unicode codepoint is returned.
+    ///
+    /// Optionally writes the event details in `input`.
+    ///
+    /// *C style function: [notcurses_getc_blocking()][crate::notcurses_getc_blocking].*
+    pub fn getc_blocking(&mut self, input: Option<&mut NcInput>) -> NcResult<char> {
+        let input_txt;
+        if cfg!(debug_assertions) {
+            input_txt = format!("{:?}", input);
+        } else {
+            input_txt = String::from("");
+        }
+
+        let res = crate::notcurses_getc_blocking(self, input);
+
+        // An invalid read is indicated with -1
+        if res as u32 as i32 != -1 {
+            return Ok(res);
+        } else {
+            error![
+                -1,
+                &format!("Notcurses.getc_blocking({:?})", input_txt),
+                res
+            ]
+        }
     }
 
     /// Gets a file descriptor suitable for input event poll()ing.
@@ -344,7 +380,7 @@ impl Notcurses {
         let mut blitter = 0;
         error![
             unsafe { crate::notcurses_lex_blitter(cstring![op], &mut blitter) },
-            blitter, "Invalid blitter name"
+            "Invalid blitter name", blitter
         ]
     }
 
@@ -365,7 +401,7 @@ impl Notcurses {
         let mut scalemode = 0;
         error![
             unsafe { crate::notcurses_lex_scalemode(cstring![op], &mut scalemode) },
-            scalemode
+            "", scalemode
         ]
     }
 
@@ -401,7 +437,10 @@ impl Notcurses {
     ///
     /// *C style function: [notcurses_mouse_enable()][crate::notcurses_mouse_enable].*
     pub fn mouse_enable(&mut self) -> NcResult<()> {
-        error![unsafe { crate::notcurses_mouse_enable(self) }]
+        error![
+            unsafe { crate::notcurses_mouse_enable(self) },
+            "Notcurses.mouse_enable()"
+        ]
     }
 
     /// Returns the number of simultaneous colors claimed to be supported,
@@ -429,6 +468,7 @@ impl Notcurses {
         let (mut y, mut x) = (0, 0);
         error![
             unsafe { crate::notcurses_refresh(self, &mut y, &mut x) },
+            "",
             (y as NcDimension, x as NcDimension)
         ]
     }
@@ -437,7 +477,10 @@ impl Notcurses {
     ///
     /// *C style function: [notcurses_render()][crate::notcurses_render].*
     pub fn render(&mut self) -> NcResult<()> {
-        error![unsafe { crate::notcurses_render(self) }]
+        error![
+            unsafe { crate::notcurses_render(self) },
+            "Notcurses.render()"
+        ]
     }
 
     /// Performs the rendering and rasterization portion of
@@ -496,31 +539,31 @@ impl Notcurses {
         }
     }
 
-    /// [notcurses_stdplane()][crate::notcurses_stdplane], plus free bonus
-    /// dimensions written to non-NULL y/x!
-    ///
-    /// *C style function: [notcurses_stddim_yx()][crate::notcurses_stddim_yx].*
-    #[inline]
-    pub fn stddim_yx<'a>(
-        nc: &'a mut Notcurses,
-        y: &mut NcDimension,
-        x: &mut NcDimension,
-    ) -> &'a mut NcPlane {
-        crate::notcurses_stddim_yx(nc, y, x)
-    }
+    // /// [notcurses_stdplane()][crate::notcurses_stdplane], plus free bonus
+    // /// dimensions written to non-NULL y/x!
+    // ///
+    // /// *C style function: [notcurses_stddim_yx()][crate::notcurses_stddim_yx].*
+    // #[inline]
+    // pub fn stddim_yx<'a>(
+    //     &'a mut self,
+    //     y: &mut NcDimension,
+    //     x: &mut NcDimension,
+    // ) -> NcResult<&'a mut NcPlane> {
+    //     crate::notcurses_stddim_yx(self, y, x)
+    // }
 
-    /// [stdplane_const()][Notcurses#method.stdplane_const], plus free
-    /// bonus dimensions written to non-NULL y/x!
-    ///
-    /// *C style function: [notcurses_stddim_yx()][crate::notcurses_stddim_yx].*
-    #[inline]
-    pub fn stddim_yx_const<'a>(
-        nc: &'a Notcurses,
-        y: &mut NcDimension,
-        x: &mut NcDimension,
-    ) -> &'a NcPlane {
-        crate::notcurses_stddim_yx_const(nc, y, x)
-    }
+    // /// [stdplane_const()][Notcurses#method.stdplane_const], plus free
+    // /// bonus dimensions written to non-NULL y/x!
+    // ///
+    // /// *C style function: [notcurses_stddim_yx()][crate::notcurses_stddim_yx].*
+    // #[inline]
+    // pub fn stddim_yx_const<'a>(
+    //     &'a self,
+    //     y: &mut NcDimension,
+    //     x: &mut NcDimension,
+    // ) -> NcResult<&'a NcPlane> {
+    //     crate::notcurses_stddim_yx_const(self, y, x)
+    // }
 
     /// Returns a mutable reference to the standard [NcPlane] for this terminal.
     ///
@@ -528,8 +571,11 @@ impl Notcurses {
     /// uppermost, leftmost cell.
     ///
     /// *C style function: [notcurses_stdplane()][crate::notcurses_stdplane].*
-    pub fn stdplane<'a>(&mut self) -> &'a mut NcPlane {
-        unsafe { &mut *crate::notcurses_stdplane(self) }
+    pub fn stdplane<'a>(&mut self) -> NcResult<&'a mut NcPlane> {
+        error_ref_mut![
+            unsafe { crate::notcurses_stdplane(self) },
+            "Notcurses.stdplane()"
+        ]
     }
 
     /// Returns a reference to the standard [NcPlane] for this terminal.
