@@ -1,10 +1,10 @@
 //! `notcurses_*` reimplemented functions.
 
-use core::ptr::null;
+use core::ptr::{null, null_mut};
 
 use crate::{
-    NcAlign, NcDimension, NcInput, NcOffset, NcPlane, NcSignalSet, NcTime, Notcurses,
-    NCALIGN_CENTER, NCALIGN_LEFT, NCALIGN_RIGHT, NCRESULT_MAX,
+    NcAlign, NcDimension, NcError, NcInput, NcOffset, NcPlane, NcResult, NcSignalSet, NcTime,
+    Notcurses, NCALIGN_CENTER, NCALIGN_LEFT, NCALIGN_RIGHT, NCRESULT_ERR, NCRESULT_MAX,
 };
 
 /// Returns the offset into `availcols` at which `cols` ought be output given
@@ -51,16 +51,25 @@ pub fn notcurses_getc_nblock(nc: &mut Notcurses, input: &mut NcInput) -> char {
     }
 }
 
-/// 'input' may be NULL if the caller is uninterested in event details.
 /// Blocks until an event is processed or a signal is received.
 ///
-/// *Method: Notcurses.[getc_nblocking()][Notcurses#method.getc_nblocking].*
+/// Optionally writes the event details in `input`.
+///
+/// In case of an invalid read (including on EOF) *-1 as char* is returned.
+///
+/// *Method: Notcurses.[getc_blocking()][Notcurses#method.getc_blocking].*
 #[inline]
-pub fn notcurses_getc_nblocking(nc: &mut Notcurses, input: &mut NcInput) -> char {
+pub fn notcurses_getc_blocking(nc: &mut Notcurses, input: Option<&mut NcInput>) -> char {
+    let input_ptr;
+    if let Some(i) = input {
+        input_ptr = i as *mut _;
+    } else {
+        input_ptr = null_mut();
+    }
     unsafe {
         let mut sigmask = NcSignalSet::new();
         sigmask.emptyset();
-        core::char::from_u32_unchecked(crate::notcurses_getc(nc, null(), &mut sigmask, input))
+        core::char::from_u32_unchecked(crate::notcurses_getc(nc, null(), &mut sigmask, input_ptr))
     }
 }
 
@@ -73,12 +82,15 @@ pub fn notcurses_stddim_yx<'a>(
     nc: &'a mut Notcurses,
     y: &mut NcDimension,
     x: &mut NcDimension,
-) -> &'a mut NcPlane {
+) -> NcResult<&'a mut NcPlane> {
     unsafe {
-        let s = crate::notcurses_stdplane(nc);
-        crate::ncplane_dim_yx(s, &mut (*y as i32), &mut (*x as i32));
-        &mut *s
+        let sp = crate::notcurses_stdplane(nc);
+        if sp != null_mut() {
+            crate::ncplane_dim_yx(sp, &mut (*y as i32), &mut (*x as i32));
+            return Ok(&mut *sp);
+        }
     }
+    Err(NcError::new(NCRESULT_ERR))
 }
 
 /// [notcurses_stdplane_const()][crate::notcurses_stdplane_const], plus free
@@ -90,12 +102,15 @@ pub fn notcurses_stddim_yx_const<'a>(
     nc: &'a Notcurses,
     y: &mut NcDimension,
     x: &mut NcDimension,
-) -> &'a NcPlane {
+) -> NcResult<&'a NcPlane> {
     unsafe {
-        let s = crate::notcurses_stdplane_const(nc);
-        crate::ncplane_dim_yx(s, &mut (*y as i32), &mut (*x as i32));
-        &*s
+        let sp = crate::notcurses_stdplane_const(nc);
+        if sp != null() {
+            crate::ncplane_dim_yx(sp, &mut (*y as i32), &mut (*x as i32));
+            return Ok(&*sp);
+        }
     }
+    Err(NcError::new(NCRESULT_ERR))
 }
 
 /// Returns our current idea of the terminal dimensions in rows and cols.
