@@ -3,9 +3,10 @@
 use core::ptr::{null, null_mut};
 
 use crate::{
-    cstring, error, error_ptr, rstring, NcAlign, NcAlphaBits, NcBoxMask, NcCell, NcChannel,
-    NcChannelPair, NcColor, NcDimension, NcEgc, NcFadeCb, NcOffset, NcPaletteIndex, NcPlane,
-    NcPlaneOptions, NcResizeCb, NcResult, NcRgb, NcStyleMask, NcTime, Notcurses,
+    cstring, error, error_ref, error_ref_mut, rstring, NcAlign, NcAlphaBits, NcBoxMask, NcCell,
+    NcChannel, NcChannelPair, NcColor, NcDimension, NcEgc, NcFadeCb, NcOffset, NcPaletteIndex,
+    NcPlane, NcPlaneOptions, NcResizeCb, NcResult, NcRgb, NcStyleMask, NcTime, Notcurses,
+    NCRESULT_ERR,
 };
 
 /// # NcPlaneOptions Constructors
@@ -67,7 +68,7 @@ impl NcPlaneOptions {
     }
 }
 
-/// # NcPlane constructors and destructors
+/// # NcPlane constructors & destructors
 impl NcPlane {
     /// New NcPlane.
     ///
@@ -80,9 +81,8 @@ impl NcPlane {
         x: NcOffset,
         rows: NcDimension,
         cols: NcDimension,
-    ) -> &'a mut NcPlane {
-        let options = NcPlaneOptions::new(y, x, rows, cols);
-        unsafe { &mut *crate::ncpile_create(nc, &options) }
+    ) -> NcResult<&'a mut NcPlane> {
+        Self::with_options(nc, NcPlaneOptions::new(y, x, rows, cols))
     }
 
     /// New NcPlane, expects an [NcPlaneOptions] struct.
@@ -90,8 +90,11 @@ impl NcPlane {
     /// The returned plane will be the top, bottom, and root of this new pile.
     ///
     /// *C style function: [ncpile_create()][crate::ncpile_create].*
-    pub fn with_options<'a>(nc: &mut Notcurses, options: NcPlaneOptions) -> &'a mut NcPlane {
-        unsafe { &mut *crate::ncpile_create(nc, &options) }
+    pub fn with_options<'a>(
+        nc: &mut Notcurses,
+        options: NcPlaneOptions,
+    ) -> NcResult<&'a mut NcPlane> {
+        error_ref_mut![unsafe { crate::ncpile_create(nc, &options) }]
     }
 
     /// New NcPlane, bound to another NcPlane.
@@ -104,8 +107,7 @@ impl NcPlane {
         rows: NcDimension,
         cols: NcDimension,
     ) -> NcResult<&'a mut NcPlane> {
-        let options = NcPlaneOptions::new(y, x, rows, cols);
-        error_ptr![unsafe { crate::ncplane_create(bound_to, &options) }]
+        Self::with_options_bound(bound_to, NcPlaneOptions::new(y, x, rows, cols))
     }
 
     /// New NcPlane, bound to another plane, expects an [NcPlaneOptions] struct.
@@ -117,7 +119,10 @@ impl NcPlane {
         bound_to: &mut NcPlane,
         options: NcPlaneOptions,
     ) -> NcResult<&'a mut NcPlane> {
-        error_ptr![unsafe { crate::ncplane_create(bound_to, &options) }]
+        error_ref_mut![
+            unsafe { crate::ncplane_create(bound_to, &options) },
+            &format!["NcPlane::with_options({:?}, {:?})", bound_to, options]
+        ]
     }
 
     /// New NcPlane, with the same dimensions of the terminal.
@@ -125,15 +130,13 @@ impl NcPlane {
     /// The returned plane will be the top, bottom, and root of this new pile.
     ///
     /// *(No equivalent C style function)*
-    pub fn new_termsize<'a>(nc: &mut Notcurses) -> &'a mut NcPlane {
+    pub fn new_termsize<'a>(nc: &mut Notcurses) -> NcResult<&'a mut NcPlane> {
         let (trows, tcols) = crate::notcurses_term_dim_yx(nc);
         assert![(trows > 0) & (tcols > 0)];
-        unsafe {
-            &mut *crate::ncpile_create(
-                nc,
-                &NcPlaneOptions::new(0, 0, trows as NcDimension, tcols as NcDimension),
-            )
-        }
+        Self::with_options(
+            nc,
+            NcPlaneOptions::new(0, 0, trows as NcDimension, tcols as NcDimension),
+        )
     }
 
     /// Destroys this NcPlane.
@@ -233,7 +236,7 @@ impl NcPlane {
     /// Sets the given [NcChannelPair]s throughout the specified region,
     /// keeping content and attributes unchanged.
     ///
-    /// Returns the number of cells set, or [NCRESULT_ERR][crate::NCRESULT_ERR]
+    /// Returns the number of cells set, or [NCRESULT_ERR]
     /// on failure.
     ///
     /// *C style function: [ncplane_stain()][crate::ncplane_stain].*
@@ -248,7 +251,7 @@ impl NcPlane {
     ) -> NcResult<NcDimension> {
         let res =
             unsafe { crate::ncplane_stain(self, y_stop as i32, x_stop as i32, ul, ur, ll, lr) };
-        error![res, res as NcDimension];
+        error![res, "", res as NcDimension];
     }
 }
 
@@ -398,7 +401,7 @@ impl NcPlane {
     /// Sets the given style throughout the specified region, keeping content
     /// and channels unchanged.
     ///
-    /// Returns the number of cells set, or [NCRESULT_ERR][crate::NCRESULT_ERR]
+    /// Returns the number of cells set, or [NCRESULT_ERR]
     /// on failure.
     ///
     /// *C style function: [ncplane_format()][crate::ncplane_format].*
@@ -410,7 +413,7 @@ impl NcPlane {
     ) -> NcResult<NcDimension> {
         let res =
             unsafe { crate::ncplane_format(self, y_stop as i32, x_stop as i32, stylemask as u32) };
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Returns the current styling for this NcPlane.
@@ -485,23 +488,25 @@ impl NcPlane {
         &mut self,
         stylemask: &mut NcStyleMask,
         channels: &mut NcChannelPair,
-    ) -> Option<NcEgc> {
+    ) -> NcResult<NcEgc> {
         let egc = unsafe { crate::ncplane_at_cursor(self, stylemask, channels) };
         if egc.is_null() {
-            return None;
+            return Err(crate::NcError::new(NCRESULT_ERR));
         }
         let egc = core::char::from_u32(unsafe { *egc } as u32).expect("wrong char");
-        Some(egc)
+        Ok(egc)
     }
 
-    /// Retrieves the current contents of the [NcCell] under the cursor.
+    /// Retrieves the current contents of the [NcCell] under the cursor
+    /// into `cell`. Returns the number of bytes in the [NcEgc].
     ///
     /// This NcCell is invalidated if the associated NcPlane is destroyed.
     ///
     /// *C style function: [ncplane_at_cursor_cell()][crate::ncplane_at_cursor_cell].*
     #[inline]
-    pub fn at_cursor_cell(&mut self, cell: &mut NcCell) -> NcResult<()> {
-        error![crate::ncplane_at_cursor_cell(self, cell)]
+    pub fn at_cursor_cell(&mut self, cell: &mut NcCell) -> NcResult<u32> {
+        let bytes = unsafe { crate::ncplane_at_cursor_cell(self, cell) };
+        error![bytes, "", bytes as u32]
     }
 
     /// Retrieves the current contents of the specified [NcCell], returning the
@@ -516,17 +521,19 @@ impl NcPlane {
         x: NcDimension,
         stylemask: &mut NcStyleMask,
         channels: &mut NcChannelPair,
-    ) -> Option<NcEgc> {
+    ) -> NcResult<NcEgc> {
         let egc = unsafe { crate::ncplane_at_yx(self, y as i32, x as i32, stylemask, channels) };
         if egc.is_null() {
-            return None;
+            return Err(crate::NcError::new(NCRESULT_ERR));
         }
         let egc = core::char::from_u32(unsafe { *egc } as u32).expect("wrong char");
-        Some(egc)
+        Ok(egc)
     }
 
     /// Retrieves the current contents of the specified [NcCell] into `cell`.
-    /// This cell is invalidated if the associated plane is destroyed.
+    /// Returns the number of bytes in the [NcEgc].
+    ///
+    /// This NcCell is invalidated if the associated plane is destroyed.
     ///
     /// *C style function: [ncplane_at_yx_cell()][crate::ncplane_at_yx_cell].*
     #[inline]
@@ -535,8 +542,9 @@ impl NcPlane {
         y: NcDimension,
         x: NcDimension,
         cell: &mut NcCell,
-    ) -> NcResult<()> {
-        error![crate::ncplane_at_yx_cell(self, y, x, cell)]
+    ) -> NcResult<u32> {
+        let bytes = unsafe { crate::ncplane_at_yx_cell(self, y as i32, x as i32, cell) };
+        error![bytes, "", bytes as u32]
     }
 
     /// Extracts this NcPlane's base [NcCell] into `cell`.
@@ -561,11 +569,17 @@ impl NcPlane {
     /// *C style function: [ncplane_set_base()][crate::ncplane_set_base].*
     pub fn set_base(
         &mut self,
-        egc: &NcEgc,
+        egc: NcEgc,
         stylemask: NcStyleMask,
         channels: NcChannelPair,
     ) -> NcResult<()> {
-        error![unsafe { crate::ncplane_set_base(self, &(*egc as i8), stylemask as u32, channels) }]
+        error![
+            unsafe { crate::ncplane_set_base(self, &(egc as i8), stylemask as u32, channels) },
+            &format!(
+                "NcPlane.set_base({:?}, {:0x}, {:0x})",
+                egc as i32, stylemask, channels
+            )
+        ]
     }
 
     /// Sets this NcPlane's base NcCell.
@@ -645,7 +659,7 @@ impl NcPlane {
         cell: &NcCell,
     ) -> NcResult<NcDimension> {
         let res = unsafe { crate::ncplane_putc_yx(self, y as i32, x as i32, cell) };
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Replaces the NcCell at the current coordinates with the provided NcCell,
@@ -657,7 +671,7 @@ impl NcPlane {
     /// *C style function: [ncplane_putc()][crate::ncplane_putc].*
     pub fn putc(&mut self, cell: &NcCell) -> NcResult<NcDimension> {
         let res = crate::ncplane_putc(self, cell);
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Calls [putchar_yx][NcPlane#method.putchar_yx] at the current cursor location.
@@ -667,7 +681,7 @@ impl NcPlane {
     /// *C style function: [ncplane_putchar()][crate::ncplane_putchar].*
     pub fn putchar(&mut self, ch: char) -> NcResult<NcDimension> {
         let res = crate::ncplane_putchar(self, ch);
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     // TODO: call put_egc
@@ -691,7 +705,7 @@ impl NcPlane {
         ch: char,
     ) -> NcResult<NcDimension> {
         let res = crate::ncplane_putchar_yx(self, y, x, ch);
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Writes a series of [NcEgc][crate::NcEgc]s to the current location,
@@ -707,7 +721,7 @@ impl NcPlane {
     #[inline]
     pub fn putstr(&mut self, string: &str) -> NcResult<NcDimension> {
         let res = crate::ncplane_putstr(self, string);
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Same as [putstr][NcPlane#method.putstr], but it also tries to move the
@@ -727,6 +741,23 @@ impl NcPlane {
         return Ok(cols);
     }
 
+    /// Same as [putstr_yx()][NcPlane#method.putstr_yx] but [NcAlign]ed on x.
+    ///
+    /// *C style function: [ncplane_putstr_aligned()][crate::ncplane_putstr_aligned].*
+    pub fn putstr_aligned(
+        &mut self,
+        y: NcDimension,
+        align: NcAlign,
+        string: &str,
+    ) -> NcResult<NcDimension> {
+        let res = unsafe { crate::ncplane_putstr_aligned(self, y as i32, align, cstring![string]) };
+        error![
+            res,
+            &format!("NcPlane.putstr_aligned({}, {}, {})", y, align, string),
+            res as NcDimension
+        ]
+    }
+
     /// Writes a series of [NcEgc][crate::NcEgc]s to the current location, but
     /// retain the styling.
     /// The current styling of the plane will not be changed.
@@ -740,7 +771,7 @@ impl NcPlane {
     /// *C style function: [ncplane_putstr_stained()][crate::ncplane_putstr_stained].*
     pub fn putstr_stained(&mut self, string: &str) -> NcResult<NcDimension> {
         let res = unsafe { crate::ncplane_putstr_stained(self, cstring![string]) };
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Write a string, which is a series of [NcEgc][crate::NcEgc]s, to the
@@ -762,7 +793,7 @@ impl NcPlane {
         string: &str,
     ) -> NcResult<NcDimension> {
         let res = unsafe { crate::ncplane_putstr_yx(self, y as i32, x as i32, cstring![string]) };
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 }
 
@@ -832,28 +863,20 @@ impl NcPlane {
     /// Returns the NcPlane above this one, or None if already at the top.
     ///
     /// *C style function: [ncplane_above()][crate::ncplane_above].*
-    pub fn above<'a>(&'a mut self) -> Option<&'a mut NcPlane> {
-        let plane = unsafe { crate::ncplane_above(self) };
-        if plane.is_null() {
-            return None;
-        }
-        Some(unsafe { &mut *plane })
+    pub fn above<'a>(&'a mut self) -> NcResult<&'a mut NcPlane> {
+        error_ref_mut![unsafe { crate::ncplane_above(self) }]
     }
 
     /// Returns the NcPlane below this one, or None if already at the bottom.
     ///
     /// *C style function: [ncplane_below()][crate::ncplane_below].*
-    pub fn below<'a>(&'a mut self) -> Option<&'a mut NcPlane> {
-        let plane = unsafe { crate::ncplane_below(self) };
-        if plane.is_null() {
-            return None;
-        }
-        Some(unsafe { &mut *plane })
+    pub fn below<'a>(&'a mut self) -> NcResult<&'a mut NcPlane> {
+        error_ref_mut![unsafe { crate::ncplane_below(self) }]
     }
 
     /// Relocates this NcPlane above the `above` NcPlane, in the z-buffer.
     ///
-    /// Returns [NCRESULT_ERR][crate::NCRESULT_ERR] if the current plane is
+    /// Returns [NCRESULT_ERR] if the current plane is
     /// already in the desired location. Both planes must not be the same.
     ///
     /// *C style function: [ncplane_move_above()][crate::ncplane_move_above].*
@@ -863,7 +886,7 @@ impl NcPlane {
 
     /// Relocates this NcPlane below the `below` NcPlane, in the z-buffer.
     ///
-    /// Returns [NCRESULT_ERR][crate::NCRESULT_ERR] if the current plane is
+    /// Returns [NCRESULT_ERR] if the current plane is
     /// already in the desired location. Both planes must not be the same.
     ///
     /// *C style function: [ncplane_move_below()][crate::ncplane_move_below].*
@@ -929,9 +952,8 @@ impl NcPlane {
     /// *C style function: [ncplane_parent()][crate::ncplane_parent].*
     //
     // TODO: CHECK: what happens when it's bound to itself.
-    // pub fn parent<'a>(&'a mut self) -> Option<&'a mut NcPlane> {
-    pub fn parent<'a>(&'a mut self) -> &'a mut NcPlane {
-        unsafe { &mut *crate::ncplane_parent(self) }
+    pub fn parent<'a>(&'a mut self) -> NcResult<&'a mut NcPlane> {
+        error_ref_mut![unsafe { crate::ncplane_parent(self) }]
     }
 
     /// Gets the parent to which this NcPlane is bound, if any.
@@ -939,9 +961,8 @@ impl NcPlane {
     /// *C style function: [ncplane_parent_const()][crate::ncplane_parent_const].*
     //
     // TODO: CHECK: what happens when it's bound to itself.
-    // pub fn parent<'a>(&'a mut self) -> Option<&'a mut NcPlane> {
-    pub fn parent_const<'a>(&'a self) -> &'a NcPlane {
-        unsafe { &*crate::ncplane_parent_const(self) }
+    pub fn parent_const<'a>(&'a self) -> NcResult<&'a NcPlane> {
+        error_ref![unsafe { crate::ncplane_parent_const(self) }]
     }
 
     /// Unbounds this NcPlane from its parent, makes it a bound child of
@@ -956,8 +977,8 @@ impl NcPlane {
     /// The standard plane cannot be reparented.
     ///
     /// *C style function: [ncplane_reparent()][crate::ncplane_reparent].*
-    pub fn reparent<'a>(&'a mut self, newparent: &'a mut NcPlane) -> &'a mut NcPlane {
-        unsafe { &mut *crate::ncplane_reparent(self, newparent) }
+    pub fn reparent<'a>(&mut self, newparent: &'a mut NcPlane) -> NcResult<&'a mut NcPlane> {
+        error_ref_mut![unsafe { crate::ncplane_reparent(self, newparent) }]
     }
 
     /// Like [`reparent`][NcPlane#method.reparent], except any bound
@@ -968,8 +989,8 @@ impl NcPlane {
     /// *C style function: [ncplane_reparent_family()][crate::ncplane_reparent_family].*
     //
     // TODO:CHECK: If 'newparent' is an ancestor, NULL is returned & no changes're made.
-    pub fn reparent_family<'a>(&'a mut self, newparent: &'a mut NcPlane) -> &'a mut NcPlane {
-        unsafe { &mut *crate::ncplane_reparent_family(self, newparent) }
+    pub fn reparent_family<'a>(&mut self, newparent: &'a mut NcPlane) -> NcResult<&'a mut NcPlane> {
+        error_ref_mut![unsafe { crate::ncplane_reparent_family(self, newparent) }]
     }
 
     /// Makes the physical screen match the last rendered frame from the pile of
@@ -996,14 +1017,14 @@ impl NcPlane {
     ///
     /// *C style function: [ncplane_notcurses()][crate::ncplane_notcurses].*
     pub fn notcurses<'a>(&mut self) -> NcResult<&'a mut Notcurses> {
-        error_ptr![unsafe { crate::ncplane_notcurses(self) }]
+        error_ref_mut![unsafe { crate::ncplane_notcurses(self) }]
     }
 
     /// Gets an immutable reference to the [Notcurses] context of this NcPlane.
     ///
     /// *C style function: [ncplane_notcurses_const()][crate::ncplane_notcurses_const].*
-    pub fn notcurses_const<'a>(&self) -> &'a Notcurses {
-        unsafe { &*crate::ncplane_notcurses_const(self) }
+    pub fn notcurses_const<'a>(&self) -> NcResult<&'a Notcurses> {
+        error_ref![unsafe { crate::ncplane_notcurses_const(self) }]
     }
 }
 
@@ -1471,7 +1492,8 @@ impl NcPlane {
         )]
     }
 
-    ///
+    /// NcPlane.[perimeter()][NcPlane#method.perimeter] with the double box-drawing characters.
+
     ///
     /// *C style function: [ncplane_perimeter_double()][crate::ncplane_perimeter_double].*
     #[inline]
@@ -1486,6 +1508,7 @@ impl NcPlane {
         )]
     }
 
+    /// NcPlane.[perimeter()][NcPlane#method.perimeter] with the rounded box-drawing characters.
     ///
     ///
     /// *C style function: [ncplane_perimeter_rounded()][crate::ncplane_perimeter_rounded].*
@@ -1567,7 +1590,7 @@ impl NcPlane {
     /// position, stopping at `y_stop` * `xstop`.
     ///
     /// Returns the number of cells filled on success,
-    /// or [NCRESULT_ERR][crate::NCRESULT_ERR] on error.
+    /// or [NCRESULT_ERR] on error.
     ///
     /// The glyph composed of `egc` and `stylemask` is used for all cells.
     /// The channels specified by `ul`, `ur`, `ll`, and `lr` are composed into
@@ -1615,7 +1638,7 @@ impl NcPlane {
                 x_stop as i32,
             )
         };
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Draw a gradient with its upper-left corner at the current cursor position,
@@ -1637,13 +1660,13 @@ impl NcPlane {
         x_len: NcDimension,
     ) -> NcResult<NcDimension> {
         let res = crate::ncplane_gradient_sized(self, egc, stylemask, ul, ur, ll, lr, y_len, x_len);
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Draws a high-resolution gradient using upper blocks and synced backgrounds.
     ///
     /// Returns the number of cells filled on success,
-    /// or [NCRESULT_ERR][crate::NCRESULT_ERR] on error.
+    /// or [NCRESULT_ERR] on error.
     ///
     /// This doubles the number of vertical gradations, but restricts you to
     /// half blocks (appearing to be full blocks).
@@ -1661,7 +1684,7 @@ impl NcPlane {
         let res = unsafe {
             crate::ncplane_highgradient(self, ul, ur, ll, lr, y_stop as i32, x_stop as i32)
         };
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// [`gradient_sized`][NcPlane#method.gradient_sized]
@@ -1680,7 +1703,7 @@ impl NcPlane {
         let res = unsafe {
             crate::ncplane_highgradient_sized(self, ul, ur, ll, lr, y_stop as i32, x_stop as i32)
         };
-        error![res, res as NcDimension]
+        error![res, "", res as NcDimension]
     }
 
     /// Converts this NcPlane's content to greyscale.
