@@ -32,9 +32,12 @@ mod methods;
 /// Either no sections are visible, and the menu is rolled up, or exactly one
 /// section is unrolled.
 ///
-/// `ncmenu_rollup` places an `NcMenu` in the rolled up state.
-/// `ncmenu_unroll` rolls up any unrolled section and unrolls the specified one.
-/// `ncmenu_destroy` removes a menu bar, and frees all associated resources.
+/// - [rollup()][NcMenu#method.rollup]
+///     places an `NcMenu` in the rolled up state.
+/// - [unroll()][NcMenu#method.unroll]
+///     rolls up any unrolled section and unrolls the specified one.
+/// - [destroy()][NcMenu#method.destroy]
+///     removes a menu bar, and frees all associated resources.
 ///
 /// `type in C: ncmenu (struct)`
 pub type NcMenu = crate::bindings::ffi::ncmenu;
@@ -48,8 +51,8 @@ pub type NcMenuItem = crate::bindings::ffi::ncmenu_item;
 /// Section for [`NcMenu`]
 pub type NcMenuSection = crate::bindings::ffi::ncmenu_section;
 
-/// Bottom row (as opposed to top row)
-pub const NCMENU_OPTION_BOTTOM: u32 = crate::bindings::ffi::NCMENU_OPTION_BOTTOM;
+/// [NcMenuOptions] flag: Bottom row (as opposed to top row).
+pub const NCMENU_OPTION_BOTTOM: u64 = crate::bindings::ffi::NCMENU_OPTION_BOTTOM as u64;
 
-/// Hide the menu when not unrolled
-pub const NCMENU_OPTION_HIDING: u32 = crate::bindings::ffi::NCMENU_OPTION_HIDING;
+/// [NcMenuOptions] flag: Hide the menu when not unrolled
+pub const NCMENU_OPTION_HIDING: u64 = crate::bindings::ffi::NCMENU_OPTION_HIDING as u64;
