@@ -9,19 +9,34 @@
 #include "notcurses/direct.h"
 #include "internal.h"
 
+static inline uint64_t
+ncdirect_channels(const ncdirect* nc){
+  return nc->channels;
+}
+
+static inline bool
+ncdirect_fg_default_p(const struct ncdirect* nc){
+  return channels_fg_default_p(ncdirect_channels(nc));
+}
+
+static inline bool
+ncdirect_bg_default_p(const struct ncdirect* nc){
+  return channels_bg_default_p(ncdirect_channels(nc));
+}
+
 int ncdirect_putstr(ncdirect* nc, uint64_t channels, const char* utf8){
   if(channels_fg_default_p(channels)){
-    if(ncdirect_fg_default(nc)){
+    if(ncdirect_fg_default_p(nc)){
       return -1;
     }
-  }else if(ncdirect_fg_rgb(nc, channels_fg_rgb(channels))){
+  }else if(ncdirect_set_fg_rgb(nc, channels_fg_rgb(channels))){
     return -1;
   }
   if(channels_bg_default_p(channels)){
-    if(ncdirect_bg_default(nc)){
+    if(ncdirect_set_bg_default(nc)){
       return -1;
     }
-  }else if(ncdirect_bg_rgb(nc, channels_bg_rgb(channels))){
+  }else if(ncdirect_set_bg_rgb(nc, channels_bg_rgb(channels))){
     return -1;
   }
   return fprintf(nc->ttyfp, "%s", utf8);
@@ -372,8 +387,10 @@ ncdirect_dump_plane(ncdirect* n, const ncplane* np, int xoff){
   ncplane_dim_yx(np, &dimy, &dimx);
 //fprintf(stderr, "rasterizing %dx%d+%d\n", dimy, dimx, xoff);
   // save the existing style and colors
-  bool fgdefault = n->fgdefault, bgdefault = n->bgdefault;
-  uint32_t fgrgb = n->fgrgb, bgrgb = n->bgrgb;
+  const bool fgdefault = ncdirect_fg_default_p(n);
+  const bool bgdefault = ncdirect_bg_default_p(n);
+  const uint32_t fgrgb = channels_fg_rgb(n->channels);
+  const uint32_t bgrgb = channels_bg_rgb(n->channels);
   for(int y = 0 ; y < dimy ; ++y){
     if(xoff){
       if(ncdirect_cursor_move_yx(n, -1, xoff)){
@@ -388,14 +405,14 @@ ncdirect_dump_plane(ncdirect* n, const ncplane* np, int xoff){
         return -1;
       }
       if(channels_fg_alpha(channels) == CELL_ALPHA_TRANSPARENT){
-        ncdirect_fg_default(n);
+        ncdirect_set_fg_default(n);
       }else{
-        ncdirect_fg_rgb(n, channels_fg_rgb(channels));
+        ncdirect_set_fg_rgb(n, channels_fg_rgb(channels));
       }
       if(channels_bg_alpha(channels) == CELL_ALPHA_TRANSPARENT){
-        ncdirect_bg_default(n);
+        ncdirect_set_bg_default(n);
       }else{
-        ncdirect_bg_rgb(n, channels_bg_rgb(channels));
+        ncdirect_set_bg_rgb(n, channels_bg_rgb(channels));
       }
 //fprintf(stderr, "%03d/%03d [%s] (%03dx%03d)\n", y, x, egc, dimy, dimx);
       if(fprintf(n->ttyfp, "%s", strlen(egc) == 0 ? " " : egc) < 0){
@@ -408,8 +425,8 @@ ncdirect_dump_plane(ncdirect* n, const ncplane* np, int xoff){
     // each line of output; this is necessary if our output is lifted out and
     // used in something e.g. paste(1).
     // FIXME replace with a SGR clear
-    ncdirect_fg_default(n);
-    ncdirect_bg_default(n);
+    ncdirect_set_fg_default(n);
+    ncdirect_set_bg_default(n);
     if(putc('\n', n->ttyfp) == EOF){
       return -1;
     }
@@ -421,33 +438,27 @@ ncdirect_dump_plane(ncdirect* n, const ncplane* np, int xoff){
   }
   // restore the previous colors
   if(fgdefault){
-    ncdirect_fg_default(n);
+    ncdirect_set_fg_default(n);
   }else{
-    ncdirect_fg_rgb(n, fgrgb);
+    ncdirect_set_fg_rgb(n, fgrgb);
   }
   if(bgdefault){
-    ncdirect_bg_default(n);
+    ncdirect_set_bg_default(n);
   }else{
-    ncdirect_bg_rgb(n, bgrgb);
+    ncdirect_set_bg_rgb(n, bgrgb);
   }
   return 0;
 }
 
-int ncdirect_raster_frame(ncdirect* n, ncdirectv* faken, ncalign_e align,
-                          ncblitter_e blitter, ncscale_e scale){
-  auto bset = rgba_blitter_low(n->utf8, n->tcache.sextants, scale, true, blitter);
-  if(!bset){
-    free_plane(faken);
-    return -1;
-  }
-  int lenx = ncplane_dim_x(faken);
+int ncdirect_raster_frame(ncdirect* n, ncdirectv* ncdv, ncalign_e align){
+  int lenx = ncplane_dim_x(ncdv);
   int xoff = ncdirect_align(n, align, lenx);
-  if(ncdirect_dump_plane(n, faken, xoff)){
-    free_plane(faken);
+  if(ncdirect_dump_plane(n, ncdv, xoff)){
+    free_plane(ncdv);
     return -1;
   }
   int r = ncdirect_flush(n);
-  free_plane(faken);
+  free_plane(ncdv);
   return r;
 }
 
@@ -494,19 +505,19 @@ ncdirectv* ncdirect_render_frame(ncdirect* n, const char* file,
     .resizecb = nullptr,
     .flags = 0,
   };
-  struct ncplane* faken = ncplane_new_internal(nullptr, nullptr, &nopts);
-  if(faken == nullptr){
+  auto ncdv = ncplane_new_internal(nullptr, nullptr, &nopts);
+  if(!ncdv){
     ncvisual_destroy(ncv);
     return nullptr;
   }
-  if(ncvisual_blit(ncv, disprows, dispcols, faken, bset,
+  if(ncvisual_blit(ncv, disprows, dispcols, ncdv, bset,
                    0, 0, 0, 0, leny, lenx, false)){
     ncvisual_destroy(ncv);
-    free_plane(faken);
+    free_plane(ncdv);
     return nullptr;
   }
   ncvisual_destroy(ncv);
-  return faken;
+  return ncdv;
 }
 
 int ncdirect_render_image(ncdirect* n, const char* file, ncalign_e align,
@@ -515,14 +526,15 @@ int ncdirect_render_image(ncdirect* n, const char* file, ncalign_e align,
   if(!faken){
     return -1;
   }
-  return ncdirect_raster_frame(n, faken, align, blitter, scale);
+  return ncdirect_raster_frame(n, faken, align);
 }
 
-int ncdirect_fg_palindex(ncdirect* nc, int pidx){
+// FIXME need to update channels
+int ncdirect_set_fg_palindex(ncdirect* nc, int pidx){
   return term_emit("setaf", tiparm(nc->tcache.setaf, pidx), nc->ttyfp, false);
 }
 
-int ncdirect_bg_palindex(ncdirect* nc, int pidx){
+int ncdirect_set_bg_palindex(ncdirect* nc, int pidx){
   return term_emit("setab", tiparm(nc->tcache.setab, pidx), nc->ttyfp, false);
 }
 
@@ -616,9 +628,8 @@ ncdirect* ncdirect_init(const char* termtype, FILE* outfp, uint64_t flags){
   if(interrogate_terminfo(&ret->tcache, shortname_term)){
     goto err;
   }
-  ret->fgdefault = ret->bgdefault = true;
-  ret->fgrgb = ret->bgrgb = 0;
-  ncdirect_styles_set(ret, 0);
+  ret->channels = 0;
+  ncdirect_set_styles(ret, 0);
   return ret;
 
 err:
@@ -675,17 +686,23 @@ ncdirect_style_emit(ncdirect* n, unsigned stylebits, FILE* out){
   }
   // sgr resets colors, so set them back up if not defaults
   if(r == 0){
-    if(!n->fgdefault){
-      r |= ncdirect_fg_rgb(n, n->fgrgb);
+    // FIXME need to handle palette-indexed colors
+    if(!ncdirect_fg_default_p(n)){
+      r |= ncdirect_set_fg_rgb(n, channels_fg_rgb(n->channels));
     }
-    if(!n->bgdefault){
-      r |= ncdirect_bg_rgb(n, n->bgrgb);
+    if(!ncdirect_bg_default_p(n)){
+      r |= ncdirect_set_bg_rgb(n, channels_bg_rgb(n->channels));
     }
   }
   return r;
 }
 
+// turn on any specified stylebits
 int ncdirect_styles_on(ncdirect* n, unsigned stylebits){
+  return ncdirect_on_styles(n, stylebits);
+}
+
+int ncdirect_on_styles(ncdirect* n, unsigned stylebits){
   uint32_t stylemask = n->stylemask | stylebits;
   if(ncdirect_style_emit(n, stylemask, n->ttyfp) == 0){
     if(term_setstyle(n->ttyfp, n->stylemask, stylemask, NCSTYLE_ITALIC,
@@ -702,8 +719,12 @@ int ncdirect_styles_on(ncdirect* n, unsigned stylebits){
   return -1;
 }
 
-// turn off any specified stylebits
 int ncdirect_styles_off(ncdirect* n, unsigned stylebits){
+  return ncdirect_off_styles(n, stylebits);
+}
+
+// turn off any specified stylebits
+int ncdirect_off_styles(ncdirect* n, unsigned stylebits){
   uint32_t stylemask = n->stylemask & ~stylebits;
   if(ncdirect_style_emit(n, stylemask, n->ttyfp) == 0){
     if(term_setstyle(n->ttyfp, n->stylemask, stylemask, NCSTYLE_ITALIC,
@@ -720,8 +741,12 @@ int ncdirect_styles_off(ncdirect* n, unsigned stylebits){
   return -1;
 }
 
-// set the current stylebits to exactly those provided
 int ncdirect_styles_set(ncdirect* n, unsigned stylebits){
+  return ncdirect_set_styles(n, stylebits);
+}
+
+// set the current stylebits to exactly those provided
+int ncdirect_set_styles(ncdirect* n, unsigned stylebits){
   uint32_t stylemask = stylebits;
   if(ncdirect_style_emit(n, stylemask, n->ttyfp) == 0){
     n->stylemask &= !(NCSTYLE_ITALIC | NCSTYLE_STRUCK); // sgr clears both
@@ -743,26 +768,42 @@ unsigned ncdirect_palette_size(const ncdirect* nc){
   return nc->tcache.colors;
 }
 
-int ncdirect_fg_default(ncdirect* nc){
-  if(term_emit("op", nc->tcache.op, nc->ttyfp, false) == 0){
-    nc->fgdefault = true;
-    if(nc->bgdefault){
-      return 0;
-    }
-    return ncdirect_bg_rgb(nc, nc->bgrgb);
+int ncdirect_set_fg_default(ncdirect* nc){
+  if(ncdirect_fg_default_p(nc)){
+    return 0;
   }
-  return -1;
+  if(nc->tcache.fgop){
+    if(term_emit("fgop", nc->tcache.fgop, nc->ttyfp, false)){
+      return -1;
+    }
+  }else if(term_emit("op", nc->tcache.op, nc->ttyfp, false) == 0){
+    if(!ncdirect_bg_default_p(nc)){
+      if(ncdirect_set_bg_rgb(nc, channels_bg_rgb(nc->channels))){
+        return -1;
+      }
+    }
+  }
+  channels_set_fg_default(&nc->channels);
+  return 0;
 }
 
-int ncdirect_bg_default(ncdirect* nc){
-  if(term_emit("op", nc->tcache.op, nc->ttyfp, false) == 0){
-    nc->bgdefault = true;
-    if(nc->fgdefault){
-      return 0;
-    }
-    return ncdirect_fg_rgb(nc, nc->fgrgb);
+int ncdirect_set_bg_default(ncdirect* nc){
+  if(ncdirect_bg_default_p(nc)){
+    return 0;
   }
-  return -1;
+  if(nc->tcache.bgop){
+    if(term_emit("bgop", nc->tcache.bgop, nc->ttyfp, false)){
+      return -1;
+    }
+  }else if(term_emit("op", nc->tcache.op, nc->ttyfp, false) == 0){
+    if(!ncdirect_fg_default_p(nc)){
+      if(ncdirect_set_fg_rgb(nc, channels_fg_rgb(nc->channels))){
+        return -1;
+      }
+    }
+  }
+  channels_set_bg_default(&nc->channels);
+  return 0;
 }
 
 int ncdirect_hline_interp(ncdirect* n, const char* egc, int len,
@@ -800,10 +841,10 @@ int ncdirect_hline_interp(ncdirect* n, const char* egc, int len,
     int bg = (deltbg * ret) / len + bg1;
     int bb = (deltbb * ret) / len + bb1;
     if(!fgdef){
-      ncdirect_fg_rgb8(n, r, g, b);
+      ncdirect_set_fg_rgb8(n, r, g, b);
     }
     if(!bgdef){
-      ncdirect_bg_rgb8(n, br, bg, bb);
+      ncdirect_set_bg_rgb8(n, br, bg, bb);
     }
     if(fprintf(n->ttyfp, "%s", egc) < 0){
       break;
@@ -878,8 +919,8 @@ int ncdirect_box(ncdirect* n, uint64_t ul, uint64_t ur,
   unsigned edges;
   edges = !(ctlword & NCBOXMASK_TOP) + !(ctlword & NCBOXMASK_LEFT);
   if(edges >= box_corner_needs(ctlword)){
-    ncdirect_fg_rgb(n, channels_fg_rgb(ul));
-    ncdirect_bg_rgb(n, channels_bg_rgb(ul));
+    ncdirect_set_fg_rgb(n, channels_fg_rgb(ul));
+    ncdirect_set_bg_rgb(n, channels_bg_rgb(ul));
     if(fprintf(n->ttyfp, "%lc", wchars[0]) < 0){
       return -1;
     }
@@ -908,8 +949,8 @@ int ncdirect_box(ncdirect* n, uint64_t ul, uint64_t ur,
   }
   edges = !(ctlword & NCBOXMASK_TOP) + !(ctlword & NCBOXMASK_RIGHT);
   if(edges >= box_corner_needs(ctlword)){
-    ncdirect_fg_rgb(n, channels_fg_rgb(ur));
-    ncdirect_bg_rgb(n, channels_bg_rgb(ur));
+    ncdirect_set_fg_rgb(n, channels_fg_rgb(ur));
+    ncdirect_set_bg_rgb(n, channels_bg_rgb(ur));
     if(fprintf(n->ttyfp, "%lc", wchars[1]) < 0){
       return -1;
     }
@@ -942,8 +983,8 @@ int ncdirect_box(ncdirect* n, uint64_t ul, uint64_t ur,
   // bottom line
   edges = !(ctlword & NCBOXMASK_BOTTOM) + !(ctlword & NCBOXMASK_LEFT);
   if(edges >= box_corner_needs(ctlword)){
-    ncdirect_fg_rgb(n, channels_fg_rgb(ll));
-    ncdirect_bg_rgb(n, channels_bg_rgb(ll));
+    ncdirect_set_fg_rgb(n, channels_fg_rgb(ll));
+    ncdirect_set_bg_rgb(n, channels_bg_rgb(ll));
     if(fprintf(n->ttyfp, "%lc", wchars[2]) < 0){
       return -1;
     }
@@ -961,8 +1002,8 @@ int ncdirect_box(ncdirect* n, uint64_t ul, uint64_t ur,
   }
   edges = !(ctlword & NCBOXMASK_BOTTOM) + !(ctlword & NCBOXMASK_RIGHT);
   if(edges >= box_corner_needs(ctlword)){
-    ncdirect_fg_rgb(n, channels_fg_rgb(lr));
-    ncdirect_bg_rgb(n, channels_bg_rgb(lr));
+    ncdirect_set_fg_rgb(n, channels_fg_rgb(lr));
+    ncdirect_set_bg_rgb(n, channels_bg_rgb(lr));
     if(fprintf(n->ttyfp, "%lc", wchars[3]) < 0){
       return -1;
     }
