@@ -304,10 +304,9 @@ typedef struct ncdirect {
   FILE* ttyfp;               // FILE* for output tty
   int ctermfd;               // fd for controlling terminal
   tinfo tcache;              // terminfo cache
-  unsigned fgrgb, bgrgb;     // last RGB values of foreground/background
+  uint64_t channels;         // current channels
   uint16_t stylemask;        // current styles
   ncinputlayer input;        // input layer; we're in cbreak mode
-  bool fgdefault, bgdefault; // are FG/BG currently using default colors?
   bool utf8;                 // are we using utf-8 encoding, as hoped?
   struct termios tpreserved; // terminal state upon entry
   // some terminals (e.g. kmscon) return cursor coordinates inverted from the
@@ -915,18 +914,18 @@ channels_blend(unsigned c1, unsigned c2, unsigned* blends){
   if(channel_alpha(c2) == CELL_ALPHA_TRANSPARENT){
     return c1; // do *not* increment *blends
   }
-  unsigned rsum, gsum, bsum;
-  channel_rgb8(c2, &rsum, &gsum, &bsum);
   bool c2default = channel_default_p(c2);
   if(*blends == 0){
     // don't just return c2, or you set wide status and all kinds of crap
     if(channel_default_p(c2)){
       channel_set_default(&c1);
     }else{
-      channel_set_rgb8(&c1, rsum, gsum, bsum);
+      channel_set(&c1, c2 & CELL_BG_RGB_MASK);
     }
     channel_set_alpha(&c1, channel_alpha(c2));
   }else if(!c2default && !channel_default_p(c1)){
+    unsigned rsum, gsum, bsum;
+    channel_rgb8(c2, &rsum, &gsum, &bsum);
     rsum = (channel_r(c1) * *blends + rsum) / (*blends + 1);
     gsum = (channel_g(c1) * *blends + gsum) / (*blends + 1);
     bsum = (channel_b(c1) * *blends + bsum) / (*blends + 1);
